.. redirect-from:: /users/prev_whats_new/github_stats_3.4.1

.. _github-stats-3-4-1:

GitHub statistics for 3.4.1 (Mar 31, 2021)
==========================================

GitHub statistics for 2021/03/26 (tag: v3.4.0) - 2021/03/31

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 7 issues and merged 20 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/61?closed=1>`__

The following 6 authors contributed 43 commits.

* Antony Lee
* Elliott Sales de Andrade
* Jody Klymak
* Thomas A Caswell
* Tim Hoffmann
* Xianxiang Li

GitHub issues and pull requests:

Pull Requests (20):

* :ghpull:`19834`: Backport PR #19812: FIX: size and color rendering for Path3DCollection
* :ghpull:`19833`: Backport PR #19811 on branch v3.4.x (Fix Inkscape cleanup at exit on Windows.)
* :ghpull:`19812`: FIX: size and color rendering for Path3DCollection
* :ghpull:`19811`: Fix Inkscape cleanup at exit on Windows.
* :ghpull:`19816`: Fix legend of colour-mapped scatter plots.
* :ghpull:`19830`: Backport PR #19824 on branch v3.4.x (Access pdf annotations while inside pikepdf.Pdf context manager.)
* :ghpull:`19829`: Backport PR #19822 on branch v3.4.x (Clarify default backend selection doc.)
* :ghpull:`19827`: Backport PR #19805 on branch v3.4.x (Fix suptitle out of layout)
* :ghpull:`19824`: Access pdf annotations while inside pikepdf.Pdf context manager.
* :ghpull:`19805`: Fix suptitle out of layout
* :ghpull:`19823`: Backport PR #19814 on branch v3.4.x (Fix positioning of annotation arrow.)
* :ghpull:`19820`: Backport PR #19817 on branch v3.4.x (Fix antialiasing with old pycairo/cairocffi.)
* :ghpull:`19814`: Fix positioning of annotation arrow.
* :ghpull:`19817`: Fix antialiasing with old pycairo/cairocffi.
* :ghpull:`19818`: Backport PR #19784 on branch v3.4.x (FIX errorbar problem with fillstyle)
* :ghpull:`19784`: FIX errorbar problem with fillstyle
* :ghpull:`19815`: Backport PR #19793 on branch v3.4.x (Fix non existent URIs)
* :ghpull:`19793`: Fix non existent URIs
* :ghpull:`19783`: Backport PR #19719 on branch v3.4.x (Respect antialiasing settings in cairo backends as well.)
* :ghpull:`19719`: Respect antialiasing settings in cairo backends as well.

Issues (7):

* :ghissue:`19779`: BUG: matplotlib 3.4.0 -- Scatter with colormap and legend gives TypeError: object of type 'NoneType' has no len()
* :ghissue:`19787`: Marker sizes in Axes3D scatter plot are changing all the time
* :ghissue:`19809`: Tests that use "image_comparison" fail to cleanup on Windows
* :ghissue:`19803`: Suptitle positioning messed up in 3.4.0
* :ghissue:`19785`: Starting point of annotation arrows has changed in 3.4.0
* :ghissue:`19776`: Errorbars with yerr fail when fillstyle is specified
* :ghissue:`19780`: redirect_from extension breaks latex build
